<?php

declare(strict_types=1);

namespace Drupal\webhook;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;

/**
 * Defines a class to build a listing of webhook type entities.
 *
 * @see \Drupal\webhook\Entity\WebhookType
 */
final class WebhookTypeListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader(): array {
    $header['label'] = $this->t('Label');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity): array {
    $row['label'] = $entity->label();
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function render(): array {
    $build = parent::render();

    $build['table']['#empty'] = $this->t(
      'No webhook types available. <a href=":link">Add webhook type</a>.',
      [':link' => Url::fromRoute('entity.webhook_type.add_form')->toString()],
    );

    return $build;
  }

}
